@@ -353,6 +353,7 @@ class App(Gtk.Application, TimerManager):
 		self.daemon.connect("device-sync-progress", self.cb_syncthing_device_sync_progress)
 		self.daemon.connect("device-sync-finished", self.cb_syncthing_device_sync_progress, 1.0)
 		self.daemon.connect("folder-added", self.cb_syncthing_folder_added)
+		self.daemon.connect("folder-error", self.cb_syncthing_folder_error)
 		self.daemon.connect("folder-data-changed", self.cb_syncthing_folder_data_changed)
 		self.daemon.connect("folder-data-failed", self.cb_syncthing_folder_state_changed, 0.0, COLOR_NEW, "")
 		self.daemon.connect("folder-sync-started", self.cb_syncthing_folder_state_changed, 0.0, COLOR_FOLDER_SYNCING, _("Syncing"))
@@ -395,6 +396,7 @@ class App(Gtk.Application, TimerManager):
 					return
 			self.ct_process()
 			self.lookup_action('daemon_output').set_enabled(True)
+			self["menu-si-daemon-output"].set_sensitive(True)
 	
 	def ct_process(self):
 		"""
@@ -987,6 +989,13 @@ class App(Gtk.Application, TimerManager):
 			folder.add_value("error", "dialog-error", _("Error"), message)
 			folder.show_value('error')
 	
+	def cb_syncthing_folder_error(self, daemon, rid, errors):
+		if rid in self.folders:	# Should be always
+			folder = self.folders[rid]
+			message = "%(path)s: %(error)s" % errors[-1]
+			folder.add_value("error", "dialog-error", _("Error"), message)
+			folder.show_value('error')
+	
 	def any_device_online(self):
 		"""
 		Returns True if there is at least one device connected to daemon
@@ -1803,13 +1812,13 @@ class App(Gtk.Application, TimerManager):
 	def cb_menu_daemon_output(self, *a):
 		if self.process != None:
 			d = DaemonOutputDialog(self, self.process)
-			d.show(self["window"])
+			d.show(None)
 	
 	def cb_menu_inotify_output(self, *a):
 		# Available & called only on Windows
 		if hasattr(self.watcher, "proc") and not self.watcher.proc is None:
 			d = DaemonOutputDialog(self, self.watcher.proc)
-			d.show(self["window"], _("Syncthing-Inotify Output"))
+			d.show(None, _("Syncthing-Inotify Output"))
 		else:
 			d = Gtk.MessageDialog(
 					self["window"],
