@@ -156,6 +156,11 @@ class Daemon(GObject.GObject, TimerManager):
 				id:		id of loaded folder
 				data:	dict with rest of folder data
 		
+		folder-error (id, errors)
+			Emited when when a folder cannot be successfully synchronized
+				id:		id of loaded folder
+				errors:	list with errors
+		
 		folder-data-changed (id, data):
 			Emited when change in folder data (/rest/model call)
 			is detected and sucesfully loaded.
@@ -247,6 +252,7 @@ class Daemon(GObject.GObject, TimerManager):
 			b"device-sync-progress"	: (GObject.SIGNAL_RUN_FIRST, None, (object, float)),
 			b"device-sync-finished"	: (GObject.SIGNAL_RUN_FIRST, None, (object,)),
 			b"folder-added"			: (GObject.SIGNAL_RUN_FIRST, None, (object, object)),
+			b"folder-error"			: (GObject.SIGNAL_RUN_FIRST, None, (object, object)),
 			b"folder-data-changed"	: (GObject.SIGNAL_RUN_FIRST, None, (object, object)),
 			b"folder-data-failed"	: (GObject.SIGNAL_RUN_FIRST, None, (object,)),
 			b"folder-sync-finished"	: (GObject.SIGNAL_RUN_FIRST, None, (object,)),
@@ -726,7 +732,7 @@ class Daemon(GObject.GObject, TimerManager):
 			try:
 				self._last_error_time = parsetime(events[-1]["time"])
 			except ValueError:
-				self._last_error_time = datetime.datetime.now()
+				self._last_error_time = datetime.now()
 			self._rest_request("system/error", self._syncthing_cb_errors)
 			self._request_events()
 		else:
@@ -753,9 +759,18 @@ class Daemon(GObject.GObject, TimerManager):
 	def _syncthing_cb_errors(self, errors):
 		if errors["errors"] is not None:
 			for e in errors["errors"]:
-				t = parsetime(e["time"])
+				if "time" in e:
+					# TODO: Remove this next time support for older daemon is dropped
+					t = parsetime(e["time"])
+					msg = e["error"]
+				elif "when" in e:
+					t = parsetime(e["when"])
+					msg = e["message"]
+				else:
+					# Can't decode this
+					continue
 				if t > self._last_error_time:
-					self.emit("error", e["error"])
+					self.emit("error", msg)
 					self._last_error_time = t
 		self.timer("errors", self._refresh_interval * 5, self._rest_request, "system/error", self._syncthing_cb_errors)
 	
@@ -1089,6 +1104,9 @@ class Daemon(GObject.GObject, TimerManager):
 		elif eType == "FolderSummary":
 			rid = e["data"]["folder"]
 			self._syncthing_cb_folder_data(e["data"]["summary"], rid)
+		elif eType == "FolderErrors":
+			rid = e["data"]["folder"]
+			self.emit("folder-error", rid, e["data"]["errors"])
 		elif eType == "ConfigSaved":
 			self.emit("config-saved")
 		elif eType == "ItemFinished":
