@@ -10,6 +10,7 @@ from gi.repository import GLib
 from base64 import b32decode
 from datetime import datetime, tzinfo, timedelta
 from subprocess import Popen
+from dateutil import parser
 import re, os, sys, platform, logging, gettext, __main__
 log = logging.getLogger("tools.py")
 
@@ -48,8 +49,9 @@ if IS_WINDOWS:
 	# On Windows, WMI and pywin32 libraries are reqired
 	import wmi, _winreg
 
-""" Localization lambda """
-_ = lambda (a) : gettext.gettext(a).decode("utf-8")
+""" Localization lambdas """
+_ = lambda(a): _uc(gettext.gettext(a))
+_uc = lambda(b): b if type(b) == unicode else b.decode("utf-8")
 
 def luhn_b32generate(s):
 	"""
@@ -148,29 +150,12 @@ class Timezone(tzinfo):
 	def dst(self, dt):
 		return timedelta(0)
 
-PARSER = re.compile(r"([-0-9]+)[A-Z]([:0-9]+)\.([0-9]+)([\-\+][0-9]+):([0-9]+)")
-PARSER_NODOT = re.compile(r"([-0-9]+)[A-Z]([:0-9]+)([\-\+][0-9]+):([0-9]+)")
-FORMAT = "%Y-%m-%d %H:%M:%S %f"
-
 def parsetime(m):
 	""" Parses time recieved from Syncthing daemon """
-	reformat, tz = None, None
-	if "." in m:
-		match = PARSER.match(m)
-		if match is None:
-			raise ValueError("Failed to parse '%s' as time" % m)
-		times = list(match.groups()[0:3])
-		times[2] = times[2][0:6]
-		reformat = "%s %s %s" % tuple(times)
-		tz = Timezone(int(match.group(4)), int(match.group(5)))
-	else:
-		match = PARSER_NODOT.match(m)
-		if match is None:
-			raise ValueError("Failed to parse '%s' as time" % m)
-		times = list(match.groups()[0:2])
-		reformat = "%s %s 00" % tuple(times)
-		tz = Timezone(int(match.group(3)), int(match.group(4)))
-	return datetime.strptime(reformat, FORMAT).replace(tzinfo=tz)
+	try:
+		return parser.parse(m)
+	except ValueError:
+		raise ValueError("Failed to parse '%s' as time" % m)
 
 def delta_to_string(d):
 	"""
